==> 1.8.2.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfLivePlayer.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;

import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.CallbackAdapter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.FUtils;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.ShowModeUtil;
import com.aliyun.roompaas.live.exposable.LivePlayerService;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel.Result;

public class FPOfLivePlayer extends FPOfBaseLive {
    private LivePlayerService playerService;

    private boolean isStarted;

    private interface API extends BaseLiveAPI {
        String start = "start";
        String pause = "pause";
        String resume = "resume";
        String stop = "stop";
        String refresh = "refresh";
    }

    @Override
    protected String getMethodChannelName() {
        return "alicloud_impinteraction_sdk_live_player";
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        super.onMethodCall(call, result);
        switch (call.method) {
            case API.start:
                start(call, result);
                break;
            case API.pause:
                pause(call, result);
                break;
            case API.resume:
                resume(call, result);
                break;
            case API.stop:
                stop(call, result);
                break;
            case API.refresh:
                refresh(call, result);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    public void start(@NonNull MethodCall call, @NonNull Result result) {
        String liveId = getLiveInstanceId();

        if (TextUtils.isEmpty(liveId)) {
            takeGeneralErr(result, " live does not exist");
            return;
        }

        LivePlayerService playerService = getPlayerService();
        int mode = ShowModeUtil.getShowMode(parseString(call, "showMode"));
        playerService.setViewContentMode(mode);

        playerService.tryPlay(new CallbackAdapter<View>(call, result) {
            @Override
            public void onSuccess(View view) {
                ViewGroup container = ofContainer();
                if (container != null) {
                    container.removeAllViews();
                    FUtils.addChildMatchParentSafely(container, view, new ViewGroup.LayoutParams(-1, -1));
                    takeSuccess(result);
                    isStarted = true;
                } else {
                    takeGeneralErr(result, "container ref cleaned");
                }
            }
        });
    }

    public void pause(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().pausePlay();
        takeSuccess(result);
    }

    public void resume(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().resumePlay();
        takeSuccess(result);
    }

    public void stop(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().stopPlay();
        isStarted = false;
        takeSuccess(result);
    }

    public void refresh(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().refreshPlay();
        takeSuccess(result);
    }

    private LivePlayerService getPlayerService() {
        if (playerService == null) {
            playerService = getLiveService().getPlayerService();
        }
        return playerService;
    }

    @Override
    public void onResume() {
        super.onResume();
        if (isStarted) {
            getPlayerService().resumePlay();
        }
    }

    @Override
    public void onPause() {
        super.onPause();
        if (isStarted) {
            getPlayerService().pausePlay();
        }
    }

    @Override
    public void onStop() {
        super.onStop();
    }

    @Override
    public void destroy() {
        super.destroy();
        playerService = null;
    }
}

==> 1.8.17.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfLivePlayer.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;

import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.CallbackAdapter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.FUtils;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.ShowModeUtil;
import com.aliyun.roompaas.live.exposable.LivePlayerService;
import com.aliyun.roompaas.player.AliLivePlayerConfig;

import java.util.Objects;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel.Result;

public class FPOfLivePlayer extends FPOfBaseLive {
    private LivePlayerService playerService;

    private boolean isStarted;

    private interface API extends BaseLiveAPI {
        String start = "start";
        String pause = "pause";
        String resume = "resume";
        String stop = "stop";
        String refresh = "refresh";
    }

    @Override
    protected String getMethodChannelName() {
        return "alicloud_impinteraction_sdk_live_player";
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        super.onMethodCall(call, result);
        switch (call.method) {
            case API.start:
                start(call, result);
                break;
            case API.pause:
                pause(call, result);
                break;
            case API.resume:
                resume(call, result);
                break;
            case API.stop:
                stop(call, result);
                break;
            case API.refresh:
                refresh(call, result);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    public void start(@NonNull MethodCall call, @NonNull Result result) {
        String liveId = getLiveInstanceId();

        if (TextUtils.isEmpty(liveId)) {
            takeGeneralErr(result, " live does not exist");
            return;
        }

        LivePlayerService playerService = getPlayerService();
        int mode = ShowModeUtil.getShowMode(parseString(call, "showMode"));
        playerService.setViewContentMode(mode);
        playerService.setPlayerConfig(new AliLivePlayerConfig(new AliLivePlayerConfig.Builder().setLowDelay(Boolean.parseBoolean(parseString(call, "lowDelay")))));

        playerService.tryPlay(new CallbackAdapter<View>(call, result) {
            @Override
            public void onSuccess(View view) {
                ViewGroup container = ofContainer();
                if (container != null) {
                    container.removeAllViews();
                    FUtils.addChildMatchParentSafely(container, view, new ViewGroup.LayoutParams(-1, -1));
                    takeSuccess(result);
                    isStarted = true;
                } else {
                    takeGeneralErr(result, "container ref cleaned");
                }
            }
        });
    }

    public void pause(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().pausePlay();
        takeSuccess(result);
    }

    public void resume(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().resumePlay();
        takeSuccess(result);
    }

    public void stop(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().stopPlay();
        isStarted = false;
        takeSuccess(result);
    }

    public void refresh(@NonNull MethodCall call, @NonNull Result result) {
        getPlayerService().refreshPlay();
        takeSuccess(result);
    }

    private LivePlayerService getPlayerService() {
        if (playerService == null || !Objects.equals(playerService, getLiveService().getPlayerService())) {
            playerService = getLiveService().getPlayerService();
        }
        return playerService;
    }

    @Override
    public void onResume() {
        super.onResume();
        if (isStarted) {
            getPlayerService().resumePlay();
        }
    }

    @Override
    public void onPause() {
        super.onPause();
        if (isStarted) {
            getPlayerService().pausePlay();
        }
    }

    @Override
    public void onStop() {
        super.onStop();
    }

    @Override
    public void destroy() {
        super.destroy();
        playerService = null;
    }
}
